Official Payabbhi Python Library
===================================

Payabbhi Python package provides client library for Payabbhi API's

Setup
-----

You can install this package by using the pip tool and installing:

    $ pip install payabbhi


Setting up a Payabbhi Account
---------------------------

Sign up for Payabbhi at https://payabbhi.com/identity/users/sign_up.

Using the Payabbhi API
--------------------

Documentation for the python bindings can be found at:

- https://payabbhi.com/docs
- https://payabbhi.com/docs/api/?python
